
    
<h1 style="color:red; text-align: center;">Omar_Style</h1>




<!-- ___
| Name | code | email |
|----|----|---|
|omar|10|omar@gamli.com|
___ -->
___
May the peace, blessings, and mercy of God be upon you. Welcome to this nice library
Also, using this library is very simple
See, in the second example, how is his office?
## note

This library is used with the Selenium library


___
### Install the library
``` bash 
pip install Omar-Style-sel
```


___

## Library use:

Here I use Firefox and Google Chrome browsers only


``` python
   
   from Omar_Style_sel import BrowsersProxy as Br

    pr = Br()
    driver = pr.proxy_firefox("74.249.8.183:3128", "http://whatismyipaddress.com")

    driver = pr.proxy_chrome("95.56.254.139:3128","http://whatismyipaddress.com")

```
____
#### Here you can only use Google Chrome, but you have to download it to your computer and then use it :

##This is the example to illustrate

``` python 
driver = pr.proxy_chrome("95.56.254.139:3128","http://whatismyipaddress.com", driver_path='E:\\chroo\\chromedriver.exe')
```
____


## Any problem contact us
[Telegram](https://t.me/OmarStyle1)

### The developer of this library
Omar_Style _ 〄


